.. _index:


Cellsino is a Python library for generating sinograms (phase and fluorescence)
of cell phantoms for testing tomographic reconstruction algorithms.
This is the documentation of cellsino version |release|.


Documentation
=============



.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
